@@ -73,22 +73,20 @@ enum
   PROP_VSCROLL_POLICY
 };
 
-#define GLADE_PLACEHOLDER_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), \
-                                               GLADE_TYPE_PLACEHOLDER,                \
-                                               GladePlaceholderPrivate))
 #define GLADE_PLACEHOLDER_PRIVATE(object) (((GladePlaceholder*)object)->priv)
 
 static void glade_placeholder_drag_init (_GladeDragInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GladePlaceholder, glade_placeholder, GTK_TYPE_WIDGET,
+                         G_ADD_PRIVATE (GladePlaceholder)
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_DRAG, 
                                                 glade_placeholder_drag_init))
 
 static void
-glade_placeholder_notify_parent (GObject *gobject,
+glade_placeholder_notify_parent (GObject    *gobject,
                                  GParamSpec *arg1,
-                                 gpointer user_data)
+                                 gpointer    user_data)
 {
   GladePlaceholder *placeholder = GLADE_PLACEHOLDER (gobject);
   GladeWidgetAdaptor *parent_adaptor = NULL;
@@ -113,7 +111,7 @@ glade_placeholder_notify_parent (GObject *gobject,
 static void
 glade_placeholder_init (GladePlaceholder *placeholder)
 {
-  placeholder->priv =  GLADE_PLACEHOLDER_GET_PRIVATE (placeholder);
+  placeholder->priv =  glade_placeholder_get_instance_private (placeholder);
 
   placeholder->priv->packing_actions = NULL;
 
@@ -151,10 +149,10 @@ glade_placeholder_finalize (GObject *object)
 }
 
 static void
-glade_placeholder_set_property (GObject *object,
-                                guint prop_id,
+glade_placeholder_set_property (GObject      *object,
+                                guint         prop_id,
                                 const GValue *value,
-                                GParamSpec *pspec)
+                                GParamSpec   *pspec)
 {
 
   switch (prop_id)
@@ -171,9 +169,9 @@ glade_placeholder_set_property (GObject *object,
 }
 
 static void
-glade_placeholder_get_property (GObject *object,
-                                guint prop_id,
-                                GValue *value,
+glade_placeholder_get_property (GObject    *object,
+                                guint       prop_id,
+                                GValue     *value,
                                 GParamSpec *pspec)
 {
   switch (prop_id)
@@ -355,22 +353,30 @@ glade_placeholder_draw (GtkWidget *widget, cairo_t *cr)
   return FALSE;
 }
 
+static void
+glade_placeholder_update_cursor (GladePlaceholder *placeholder, GdkWindow *win)
+{
+  GladeProject *project = glade_placeholder_get_project (placeholder);
+  GladePointerMode pointer_mode = glade_project_get_pointer_mode (project);
+
+  if (pointer_mode == GLADE_POINTER_SELECT)
+    glade_cursor_set (project, win, GLADE_CURSOR_SELECTOR);
+  else if (pointer_mode == GLADE_POINTER_ADD_WIDGET)
+    glade_cursor_set (project, win, GLADE_CURSOR_ADD_WIDGET);
+}
+
+static gboolean
+glade_placeholder_enter_notify_event (GtkWidget        *widget, 
+                                      GdkEventCrossing *event)
+{
+  glade_placeholder_update_cursor (GLADE_PLACEHOLDER (widget), event->window);
+  return FALSE;
+}
+
 static gboolean
 glade_placeholder_motion_notify_event (GtkWidget *widget, GdkEventMotion *event)
 {
-  GladePointerMode pointer_mode;
-  GladeProject *project;
-
-  g_return_val_if_fail (GLADE_IS_PLACEHOLDER (widget), FALSE);
-
-  project      = glade_placeholder_get_project (GLADE_PLACEHOLDER (widget));
-  pointer_mode = glade_project_get_pointer_mode (project);
-
-  if (pointer_mode == GLADE_POINTER_SELECT)
-    glade_cursor_set (project, event->window, GLADE_CURSOR_SELECTOR);
-  else if (pointer_mode == GLADE_POINTER_ADD_WIDGET)
-    glade_cursor_set (project, event->window, GLADE_CURSOR_ADD_WIDGET);
-
+  glade_placeholder_update_cursor (GLADE_PLACEHOLDER (widget), event->window);
   return FALSE;
 }
 
@@ -539,6 +545,7 @@ glade_placeholder_class_init (GladePlaceholderClass *klass)
   widget_class->unmap = glade_placeholder_unmap;
   widget_class->size_allocate = glade_placeholder_size_allocate;
   widget_class->draw = glade_placeholder_draw;
+  widget_class->enter_notify_event = glade_placeholder_enter_notify_event;
   widget_class->motion_notify_event = glade_placeholder_motion_notify_event;
   widget_class->button_press_event = glade_placeholder_button_press;
   widget_class->popup_menu = glade_placeholder_popup_menu;
@@ -565,8 +572,6 @@ glade_placeholder_class_init (GladePlaceholderClass *klass)
       cairo_pattern_set_extend (placeholder_pattern, CAIRO_EXTEND_REPEAT);
     }
   g_free (path);
-
-  g_type_class_add_private (klass, sizeof (GladePlaceholderPrivate));
 }
 
 /**
