@@ -31,9 +31,6 @@
 
 /* --------------------------------- Constants ------------------------------ */
 
-#define FIXED_DEFAULT_CHILD_WIDTH  100
-#define FIXED_DEFAULT_CHILD_HEIGHT 60
-
 #define MNEMONIC_INSENSITIVE_MSG   _("This property does not apply unless Use Underline is set.")
 #define NOT_SELECTED_MSG           _("Property not selected")
 #define RESPID_INSENSITIVE_MSG     _("This property is only for use in dialog action buttons")
@@ -41,19 +38,9 @@
 
 #define ONLY_THIS_GOES_IN_THAT_MSG _("Only objects of type %s can be added to objects of type %s.")
 
-G_BEGIN_DECLS
+#define ACTION_ACCEL_INSENSITIVE_MSG _("The accelerator can only be set when inside an Action Group.")
 
-/* Shared functions */
-void
-glade_gtk_box_notebook_child_insert_remove_action (GladeWidgetAdaptor * adaptor,
-                                                   GObject * container,
-                                                   GObject * object,
-                                                   const gchar * size_prop,
-                                                   const gchar * group_format,
-                                                   gboolean remove,
-                                                   gboolean after);
-
-
-G_END_DECLS
+#define GLADE_TAG_ATTRIBUTES        "attributes"
+#define GLADE_TAG_ATTRIBUTE         "attribute"
 
 #endif /* __GLADE_GTK_H__ */
