@@ -47,40 +47,35 @@ struct _GladeImageEditorPrivate
 static GladeEditableIface *parent_editable_iface;
 
 G_DEFINE_TYPE_WITH_CODE (GladeImageEditor, glade_image_editor, GLADE_TYPE_EDITOR_SKELETON,
+                         G_ADD_PRIVATE (GladeImageEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
                                                 glade_image_editor_editable_init));
 
 static void
 glade_image_editor_class_init (GladeImageEditorClass * klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   widget_class->grab_focus = glade_image_editor_grab_focus;
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/gladegtk/glade-image-editor.ui");
 
-  gtk_widget_class_bind_child (widget_class, GladeImageEditorPrivate, embed);
-  gtk_widget_class_bind_child (widget_class, GladeImageEditorPrivate, stock_radio);
-  gtk_widget_class_bind_child (widget_class, GladeImageEditorPrivate, icon_radio);
-  gtk_widget_class_bind_child (widget_class, GladeImageEditorPrivate, resource_radio);
-  gtk_widget_class_bind_child (widget_class, GladeImageEditorPrivate, file_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeImageEditor, embed);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeImageEditor, stock_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeImageEditor, icon_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeImageEditor, resource_radio);
+  gtk_widget_class_bind_template_child_private (widget_class, GladeImageEditor, file_radio);
 
-  gtk_widget_class_bind_callback (widget_class, stock_toggled);
-  gtk_widget_class_bind_callback (widget_class, icon_toggled);
-  gtk_widget_class_bind_callback (widget_class, resource_toggled);
-  gtk_widget_class_bind_callback (widget_class, file_toggled);
-
-  g_type_class_add_private (object_class, sizeof (GladeImageEditorPrivate));  
+  gtk_widget_class_bind_template_callback (widget_class, stock_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, icon_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, resource_toggled);
+  gtk_widget_class_bind_template_callback (widget_class, file_toggled);
 }
 
 static void
 glade_image_editor_init (GladeImageEditor * self)
 {
-  self->priv = 
-    G_TYPE_INSTANCE_GET_PRIVATE (self,
-				 GLADE_TYPE_IMAGE_EDITOR,
-				 GladeImageEditorPrivate);
+  self->priv = glade_image_editor_get_instance_private (self);
 
   gtk_widget_init_template (GTK_WIDGET (self));
 }
